/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.event.world;

import com.flowpowered.math.vector.Vector3i;
import org.spongepowered.api.event.GameEvent;
import org.spongepowered.api.world.ChunkManager;

/**
 * Represents a {@link org.spongepowered.api.world.ChunkManager.LoadingTicket}
 * forcing a chunk to load into the world. Note that the loading ticket may
 * have not finished so the chunk may not have finished loading yet.
 */
public interface ChunkForcedEvent extends GameEvent {

    /**
     * Gets the ticket that the chunk was added to.
     *
     * @return The ticket the chunk was added to
     */
    ChunkManager.LoadingTicket getTicket();

    /**
     * Gets the added chunk coordinates.
     *
     * @return The coordinated of the added chunk
     */
    Vector3i getChunkCoords();
}
