/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.world.gen;

import org.spongepowered.api.world.World;

import java.util.Random;

/**
 * Represents an object placed in the world during terrain population. Populator
 * objects typically fit in a single chunk.
 *
 * @see PopulatorObjects
 */
public interface PopulatorObject {

    /**
     * Returns whether this object can be placed into the world at the given
     * position.
     *
     * @param world The world
     * @param x The X position
     * @param y The Y position
     * @param z The Z position
     * @return Whether the placement is valid
     */
    boolean canPlaceAt(World world, int x, int y, int z);

    /**
     * Places the object into the world at the given location.
     *
     * @param world The world
     * @param random Random number generator based on the world seed and
     *        position.
     * @param x The X position
     * @param y The Y position
     * @param z The Z position
     */
    void placeObject(World world, Random random, int x, int y, int z);

}
